Author Build Commit PR
amatsuda 25365 9b116f1 n/a
Repo Branch
rails/rails main
Message
Merge pull request #59405 from czj/perf/collection-replace-50848 Index existing attachments once when attaching to a collection, 1.6x faster alone and 63x with #58679

/api

Reference documentation

/guides

In-depth tutorials